@@ -43,10 +43,10 @@ class DistributionCache(metadata.PathDistribution):
             distribution = None
         if distribution is None:
             raise ModuleError(name)
+        self.original = distribution
+
         # Cache dist-info files in a temporary directory
-        normalized_name = getattr(distribution, "_normalized_name", None)
-        if normalized_name is None:
-            normalized_name = metadata.Prepared.normalize(name)
+        normalized_name = self.normalized_name
         source_path = getattr(distribution, "_path", None)
         if source_path is None:
             mask = f"{normalized_name}-{distribution.version}.*-info"
@@ -62,13 +62,12 @@ class DistributionCache(metadata.PathDistribution):
         dist_name = f"{normalized_name}-{distribution.version}.dist-info"
         target_path = cache_path / dist_name
         super().__init__(target_path)
-        self.original = distribution
-        self.normalized_name = normalized_name
         self.distinfo_name = dist_name
-        if target_path.exists():  # cached
+        if target_path.exists():  # already cached
             return
-        target_path.mkdir(parents=True)
 
+        # Copy data from dist-info directory or create it.
+        target_path.mkdir(parents=True)
         purelib = None
         if source_path.name.endswith(".dist-info"):
             for source in source_path.rglob("*"):  # type: Path
@@ -101,6 +100,17 @@ class DistributionCache(metadata.PathDistribution):
         self._write_wheel_distinfo(purelib)
         self._write_record_distinfo()
 
+    @property
+    def name(self) -> str:
+        return self.original.metadata["Name"]
+
+    @property
+    def normalized_name(self) -> str:
+        normalized_name = getattr(self.original, "_normalized_name", None)
+        if normalized_name is None:
+            normalized_name = metadata.Prepared.normalize(self.name)
+        return normalized_name
+
     def _write_wheel_distinfo(self, purelib: bool) -> None:
         """Create a WHEEL file if it doesn't exist."""
         target = self.locate_file(f"{self.distinfo_name}/WHEEL")
@@ -132,16 +142,13 @@ class DistributionCache(metadata.PathDistribution):
     @property
     def binary_files(self) -> list[str]:
         """Return the binary files included in the package."""
+        files = self.original.files or []
         if IS_MINGW or IS_WINDOWS:
-            return [
-                file
-                for file in self.original.files
-                if file.suffix.lower() == ".dll"
-            ]
+            return [file for file in files if file.suffix.lower() == ".dll"]
         extensions = tuple([ext for ext in EXTENSION_SUFFIXES if ext != ".so"])
         return [
             file
-            for file in self.original.files
+            for file in files
             if file.match("*.so*") and not file.name.endswith(extensions)
         ]
 
@@ -228,9 +235,7 @@ class Module:
             del self.__dict__["stub_code"]  # clear the cache
         if not filename:
             return None
-        if isinstance(filename, str):
-            filename = Path(filename)
-        return filename
+        return Path(filename)
 
     @cached_property
     def root_dir(self) -> Path | None:
@@ -357,7 +362,7 @@ class Module:
                 root_name = self.root.name.lower()
                 try:
                     hook_cls = resolve_name(
-                        f"cx_Freeze.hooks.{root_name}:Hook"
+                        f"cx_Freeze.hooks._{root_name}_:Hook"
                     )
                 except (AttributeError, ValueError):
                     hook_cls = None
@@ -368,7 +373,7 @@ class Module:
                     name = self.name.replace(".", "_").lower()
                     try:
                         func = resolve_name(
-                            f"cx_Freeze.hooks.{root_name}:load_{name}"
+                            f"cx_Freeze.hooks._{root_name}_:load_{name}"
                         )
                     except (AttributeError, ValueError):
                         pass
@@ -441,7 +446,7 @@ class ConstantsModule:
     ) -> None:
         self.module_name: str = module_name
         self.time_format: str = time_format
-        self.values: dict[str, str] = {}
+        self.values: dict[str, str | int | float] = {}
         self.values["BUILD_RELEASE_STRING"] = release_string
         self.values["BUILD_COPYRIGHT"] = copyright_string
         if constants:
@@ -452,11 +457,12 @@ class ConstantsModule:
                     value = None
                 else:
                     name, string_value = parts
-                    value = ast.literal_eval(string_value)
-                if (not name.isidentifier()) or iskeyword(name):
-                    msg = (
-                        f"Invalid constant name in ConstantsModule ({name!r})"
-                    )
+                    if string_value:
+                        value = ast.literal_eval(string_value)
+                    else:
+                        value = string_value
+                if not name.isidentifier() or iskeyword(name):
+                    msg = f"Invalid constant name ({name!r})"
                     raise OptionError(msg)
                 self.values[name] = value
 
@@ -467,15 +473,12 @@ class ConstantsModule:
         today = datetime.now(tz=timezone.utc)
         source_timestamp = 0
         for module in modules:
-            if module.file is None:
+            if (
+                module.file is None
+                or not module.file.exists()
+                or module.source_is_zip_file
+            ):
                 continue
-            if module.source_is_zip_file:
-                continue
-            if not module.file.exists():
-                msg = (
-                    f"No file named {module.file!s} (for module {module.name})"
-                )
-                raise OptionError(msg)
             timestamp = module.file.stat().st_mtime
             source_timestamp = max(source_timestamp, timestamp)
         stamp = datetime.fromtimestamp(source_timestamp, tz=timezone.utc)
